encode_java

Function encode_java 

pub fn encode_java(c: char, dst: &mut [u8]) -> &mut [u8]
Encodes a character as Java CESU-8 into the provided byte buffer, then returns the subslice of the buffer that contains the encoded character.