EncodingError

Struct EncodingError 

pub struct EncodingError { /* private fields */ }
Errors which can occur when attempting to interpret a sequence of u8 as a string.

As such, the from_slice function for both Cesu8Str and JavaStr make use of this error.

Implementations

Source

impl EncodingError

pub fn valid_up_to(&self) -> usize

Returns the index in the given string up to which valid CESU-8 or Java CESU-8 was verified.

It is the maximum index such that from_slice of either Cesu8Str or JavaStr would return Ok(_).

pub fn error_len(&self) -> Option<NonZeroU8>

Provides more information about the failure:

  • None: the end of the input was reached unexpectedly. self.valid_up_to() is 1 to 6 bytes from the end of the input. If a byte stream (such as a file or network socket) is being decoded incrementally, this could be a valid char whose UTF-8 byte sequence is spanning multiple chunks.
  • Some(len): an unexpected byte was encountered. The length provided is that of the invalid byte seqence that starts at the index given by valid_up_to().